==> templejs-bootstrap-modal-1.1.1.tgz: package/index.js <==
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var Temple = require('templejs');
var Temple__default = _interopDefault(Temple);
var lodash = require('lodash');

var babelHelpers = {};
babelHelpers.typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
  return typeof obj;
} : function (obj) {
  return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj;
};
babelHelpers;

Temple.registerType("bs-modal-base", function () {
	this.use("actions");
	this.decorate("absorb-attrs", function (d, obj, toOmit) {
		if (!obj || (typeof obj === "undefined" ? "undefined" : babelHelpers.typeof(obj)) !== "object") return;
		toOmit = [].concat(toOmit, ["text", "className"]).filter(Boolean);
		lodash.forEach(lodash.omit(obj, toOmit), function (value, name) {
			Temple.idom.updateAttribute(d.target, name, value);
		});
	});
});

var Template = {};
var idom$1 = Temple__default.idom;

var decorators = Temple__default.decorators;

Template["bs-modal-content"] = Temple__default.create("bs-modal-content", "bs-modal-base", function (scope, key) {
  idom$1.text(" ");
  idom$1.elementOpen("div", key + "-1");
  decorators.render(scope, "class", function (scope) {
    return ["modal-dialog", scope.lookup("large") ? Temple__default.utils.joinValues(" modal-lg") : ''].map(Temple__default.utils.toString).join("");
  });
  idom$1.text(" ");
  Temple__default.Element("div", "1", scope, function (scope) {
    decorators.render(scope, "class", "modal-content");
    idom$1.text(" ");
    if (scope.lookup("form")) {
      idom$1.text(" ");
      Temple__default.Element("form", "1-0-1", scope, function (scope) {
        decorators.render(scope, "on-keydown", "confirm-on-enter");
        decorators.render(scope, "on-submit", function (scope) {
          return ["confirm", scope.lookup("onconfirm")];
        });
        decorators.render(scope, "absorb-attrs", function (scope) {
          return scope.lookup("form");
        });
        idom$1.text(" ");
        Temple__default.render("bs-modal-body", scope, "1");
        idom$1.text(" ");
      });
      idom$1.text(" ");
    } else {
      idom$1.text(" ");
      Temple__default.render("bs-modal-body", scope, "1-1-1");
      idom$1.text(" ");
    }
    idom$1.text(" ");
  });
  idom$1.text(" ");
  idom$1.elementClose("div");
  idom$1.text(" ");
});

Template["bs-modal-content"].actions({
  confirm: function confirm(e, onconfirm) {
    if (typeof onconfirm !== "function") return;
    e.original.preventDefault();
    onconfirm();
  }
});

Template["bs-modal-body"] = Temple__default.create("bs-modal-body", "bs-modal-base", function (scope, key) {
  idom$1.text(" ");
  if (scope.lookup("header")) {
    Temple__default.With(scope.lookup("header"), scope, function (scope) {
      idom$1.text(" ");
      Temple__default.render("bs-modal-header", scope, key + "-1-0-0-1");
      idom$1.text(" ");
    });
  }
  idom$1.text(" ");
  Temple__default.Element("div", key + "-3", scope, function (scope) {
    decorators.render(scope, "class", "modal-body");
    idom$1.text(" ");
    if (scope.lookup("contentTemplate")) {
      idom$1.text(" ");
      Temple__default.render(scope.lookup("contentTemplate"), scope, "1-0-1");
      idom$1.text(" ");
    } else if (scope.lookup("content")) {
      idom$1.text(" ");
      idom$1.autotext(function () {
        return scope.lookup("content");
      });
      idom$1.text(" ");
    }
    idom$1.text(" ");
  });
  idom$1.text(" ");
  if (scope.lookup("footer")) {
    Temple__default.With(scope.lookup("footer"), scope, function (scope) {
      idom$1.text(" ");
      Temple__default.render("bs-modal-footer", scope, key + "-5-0-0-1");
      idom$1.text(" ");
    });
  }
  idom$1.text(" ");
});

Template["bs-modal-header"] = Temple__default.create("bs-modal-header", "bs-modal-base", function (scope, key) {
  idom$1.text(" ");
  Temple__default.Element("div", key + "-1", scope, function (scope) {
    decorators.render(scope, "class", "modal-header");
    idom$1.text(" ");
    if (scope.lookup("close")) {
      idom$1.text(" ");
      idom$1.elementOpen("button", "1-0-1");
      decorators.render(scope, "type", "button");
      decorators.render(scope, "class", "close");
      decorators.render(scope, "data-dismiss", "modal");
      idom$1.text(Temple__default.utils.decodeEntities("&times;"));
      idom$1.elementClose("button");
      idom$1.text(" ");
    }
    idom$1.text(" ");
    idom$1.elementOpen("h4", "3");
    decorators.render(scope, "class", "modal-title");
    idom$1.autotext(function () {
      return scope.lookup("title");
    });
    idom$1.elementClose("h4");
    idom$1.text(" ");
  });
  idom$1.text(" ");
});

Template["bs-modal-footer"] = Temple__default.create("bs-modal-footer", "bs-modal-base", function (scope, key) {
  idom$1.text(" ");
  Temple__default.Element("div", key + "-1", scope, function (scope) {
    decorators.render(scope, "class", "modal-footer");
    idom$1.text(" ");
    if (scope.lookup("help")) {
      idom$1.text(" ");
      idom$1.elementOpen("span", "1-0-1");
      decorators.render(scope, "class", "pull-left");
      idom$1.autotext(function () {
        return scope.lookup("help");
      });
      idom$1.elementClose("span");
      idom$1.text(" ");
    }
    idom$1.text(" ");
    scope.set("closeData", scope.lookup("closeBtnData").call(scope.lookup(), scope.lookup("close")));
    idom$1.text(" ");
    if (scope.lookup("closeData")) {
      Temple__default.With(scope.lookup("closeData"), scope, function (scope) {
        idom$1.text(" ");
        idom$1.elementOpen("button", "5-0-0-1");
        decorators.render(scope, "class", function (scope) {
          return ["btn ", scope.lookup("className")].map(Temple__default.utils.toString).join("");
        });
        decorators.render(scope, "data-dismiss", "modal");
        decorators.render(scope, "absorb-attrs", function (scope) {
          return scope.lookup();
        });
        idom$1.text(" ");
        idom$1.autotext(function () {
          return scope.lookup("text");
        });
        idom$1.text(" ");
        idom$1.elementClose("button");
        idom$1.text(" ");
      });
    }
    idom$1.text(" ");
    scope.set("confirmData", scope.lookup("confirmBtnData").call(scope.lookup(), scope.lookup("confirm")));
    idom$1.text(" ");
    if (scope.lookup("confirmData")) {
      Temple__default.With(scope.lookup("confirmData"), scope, function (scope) {
        idom$1.text(" ");
        if (scope.lookup("form")) {
          idom$1.text(" ");
          idom$1.elementOpen("button", "9-0-0-1-0-1");
          decorators.render(scope, "type", "submit");
          decorators.render(scope, "class", function (scope) {
            return ["btn ", scope.lookup("className")].map(Temple__default.utils.toString).join("");
          });
          decorators.render(scope, "absorb-attrs", function (scope) {
            return scope.lookup();
          });
          idom$1.text(" ");
          idom$1.autotext(function () {
            return scope.lookup("text");
          });
          idom$1.text(" ");
          idom$1.elementClose("button");
          idom$1.text(" ");
        } else {
          idom$1.text(" ");
          idom$1.elementOpen("button", "9-0-0-1-1-1");
          decorators.render(scope, "class", function (scope) {
            return ["btn ", scope.lookup("className")].map(Temple__default.utils.toString).join("");
          });
          decorators.render(scope, "on-click", function (scope) {
            return ["confirm", scope.lookup("onconfirm")];
          });
          decorators.render(scope, "absorb-attrs", function (scope) {
            return scope.lookup();
          });
          idom$1.text(" ");
          idom$1.autotext(function () {
            return scope.lookup("text");
          });
          idom$1.text(" ");
          idom$1.elementClose("button");
          idom$1.text(" ");
        }
        idom$1.text(" ");
      });
    }
    idom$1.text(" ");
  });
  idom$1.text(" ");
});

Template["bs-modal-footer"].helpers({
  closeBtnData: function closeBtnData(value) {
    if (!value) return false;
    if (typeof value === "string") value = { text: value };
    return lodash.assign({ text: "Close", className: "btn-secondary" }, value);
  },
  confirmBtnData: function confirmBtnData(value) {
    if (!value) return false;
    if (typeof value === "string") value = { text: value };
    return lodash.assign({ text: "Confirm", className: "btn-success" }, value);
  }
});

function createContainer() {
	var data = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
	var id = data.id;
	var className = data.className;

	var cont = document.createElement("div");
	if (id) cont.id = id;
	cont.classList.add("modal", "fade");
	if (className) cont.classList.add(className);
	return cont;
}

function create(node) {
	var data = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

	if (node && !node.nodeType) {
		;

		var _ref = [node, null];
		data = _ref[0];
		node = _ref[1];
	}var cont = createContainer(data);
	data = lodash.merge({
		form: false,
		header: true,
		footer: true,
		close: true,
		confirm: false,
		destroyOnHide: true
	}, data);

	var comp = Temple__default.paint("bs-modal-content", cont, data);

	var $el = comp.$el = jQuery(cont);
	comp.container = cont;

	comp.appendTo = function (node) {
		if (typeof node === "string") node = document.querySelector(node);
		node.appendChild(cont);
		return comp;
	};

	comp.show = function (node) {
		if (node) comp.appendTo(node);else if (!comp.container.parentNode) comp.appendTo("body");
		$el.modal("show");
		return comp;
	};

	comp.hide = function () {
		$el.modal("hide");
		return comp;
	};

	comp.destroy = function () {
		comp.stop();
		if (cont.parentNode) {
			cont.parentNode.removeChild(cont);
		}
	};

	$el.on("hidden.bs.modal", function () {
		if (data.destroyOnHide) comp.destroy();
	});

	if (node) comp.appendTo(node);

	return comp;
}

function open(node, data) {
	if (node && !node.nodeType) {
		;
		var _ref2 = [node, null];
		data = _ref2[0];
		node = _ref2[1];
	}var modal = create(node, data);
	modal.show();
	return modal;
}

function confirm(msg, data, fn) {
	if (typeof data === "function") {
		;

		var _ref3 = [data, {}];
		fn = _ref3[0];
		data = _ref3[1];
	}return open(document.body, lodash.merge({
		content: msg,
		onconfirm: fn,
		header: false,
		footer: {
			close: "Cancel",
			confirm: { className: "btn-primary", text: "Okay" }
		},
		className: "modal-confirm"
	}, data));
}

exports.createContainer = createContainer;
exports.create = create;
exports.open = open;
exports.confirm = confirm;

==> templejs-bootstrap-modal-1.2.0.tgz: package/index.js <==
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var Temple = require('templejs');
var Temple__default = _interopDefault(Temple);
var lodash = require('lodash');

var babelHelpers = {};
babelHelpers.typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
  return typeof obj;
} : function (obj) {
  return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj;
};
babelHelpers;

Temple.registerType("bs-modal-base", function () {
	this.use("actions");
	this.decorate("absorb-attrs", function (d, obj, toOmit) {
		if (!obj || (typeof obj === "undefined" ? "undefined" : babelHelpers.typeof(obj)) !== "object") return;
		toOmit = [].concat(toOmit, ["text", "className"]).filter(Boolean);
		lodash.forEach(lodash.omit(obj, toOmit), function (value, name) {
			Temple.idom.updateAttribute(d.target, name, value);
		});
	});
});

var Template = {};
var idom$1 = Temple__default.idom;

var decorators = Temple__default.decorators;

Template["bs-modal-content"] = Temple__default.create("bs-modal-content", "bs-modal-base", function (scope, key) {
  idom$1.text(" ");
  idom$1.elementOpen("div", key + "-1");
  decorators.render(scope, "class", function (scope) {
    return ["modal-dialog", scope.lookup("large") ? Temple__default.utils.joinValues(" modal-lg") : ''].map(Temple__default.utils.toString).join("");
  });
  idom$1.text(" ");
  Temple__default.Element("div", "1", scope, function (scope) {
    decorators.render(scope, "class", "modal-content");
    idom$1.text(" ");
    if (scope.lookup("form")) {
      idom$1.text(" ");
      Temple__default.Element("form", "1-0-1", scope, function (scope) {
        decorators.render(scope, "on-keydown", "confirm-on-enter");
        decorators.render(scope, "on-submit", function (scope) {
          return ["confirm", scope.lookup("onconfirm")];
        });
        decorators.render(scope, "absorb-attrs", function (scope) {
          return scope.lookup("form");
        });
        idom$1.text(" ");
        Temple__default.render("bs-modal-body", scope, "1");
        idom$1.text(" ");
      });
      idom$1.text(" ");
    } else {
      idom$1.text(" ");
      Temple__default.render("bs-modal-body", scope, "1-1-1");
      idom$1.text(" ");
    }
    idom$1.text(" ");
  });
  idom$1.text(" ");
  idom$1.elementClose("div");
  idom$1.text(" ");
});

Template["bs-modal-content"].actions({
  confirm: function confirm(e, onconfirm) {
    e.original.preventDefault();
    if (typeof onconfirm === "function") onconfirm();

    var hideOnConfirm = e.scope.lookup("hideOnConfirm");
    var hide = e.scope.lookup("invokeHide");
    if (hideOnConfirm && hide) hide();
  }
});

Template["bs-modal-body"] = Temple__default.create("bs-modal-body", "bs-modal-base", function (scope, key) {
  idom$1.text(" ");
  if (scope.lookup("header")) {
    Temple__default.With(scope.lookup("header"), scope, function (scope) {
      idom$1.text(" ");
      Temple__default.render("bs-modal-header", scope, key + "-1-0-0-1");
      idom$1.text(" ");
    });
  }
  idom$1.text(" ");
  Temple__default.Element("div", key + "-3", scope, function (scope) {
    decorators.render(scope, "class", "modal-body");
    idom$1.text(" ");
    if (scope.lookup("contentTemplate")) {
      idom$1.text(" ");
      Temple__default.render(scope.lookup("contentTemplate"), scope, "1-0-1");
      idom$1.text(" ");
    } else if (scope.lookup("content")) {
      idom$1.text(" ");
      idom$1.autotext(function () {
        return scope.lookup("content");
      });
      idom$1.text(" ");
    }
    idom$1.text(" ");
  });
  idom$1.text(" ");
  if (scope.lookup("footer")) {
    Temple__default.With(scope.lookup("footer"), scope, function (scope) {
      idom$1.text(" ");
      Temple__default.render("bs-modal-footer", scope, key + "-5-0-0-1");
      idom$1.text(" ");
    });
  }
  idom$1.text(" ");
});

Template["bs-modal-header"] = Temple__default.create("bs-modal-header", "bs-modal-base", function (scope, key) {
  idom$1.text(" ");
  Temple__default.Element("div", key + "-1", scope, function (scope) {
    decorators.render(scope, "class", "modal-header");
    idom$1.text(" ");
    if (scope.lookup("close")) {
      idom$1.text(" ");
      idom$1.elementOpen("button", "1-0-1");
      decorators.render(scope, "type", "button");
      decorators.render(scope, "class", "close");
      decorators.render(scope, "data-dismiss", "modal");
      idom$1.text(Temple__default.utils.decodeEntities("&times;"));
      idom$1.elementClose("button");
      idom$1.text(" ");
    }
    idom$1.text(" ");
    idom$1.elementOpen("h4", "3");
    decorators.render(scope, "class", "modal-title");
    idom$1.autotext(function () {
      return scope.lookup("title");
    });
    idom$1.elementClose("h4");
    idom$1.text(" ");
  });
  idom$1.text(" ");
});

Template["bs-modal-footer"] = Temple__default.create("bs-modal-footer", "bs-modal-base", function (scope, key) {
  idom$1.text(" ");
  Temple__default.Element("div", key + "-1", scope, function (scope) {
    decorators.render(scope, "class", "modal-footer");
    idom$1.text(" ");
    if (scope.lookup("help")) {
      idom$1.text(" ");
      idom$1.elementOpen("span", "1-0-1");
      decorators.render(scope, "class", "pull-left");
      idom$1.autotext(function () {
        return scope.lookup("help");
      });
      idom$1.elementClose("span");
      idom$1.text(" ");
    }
    idom$1.text(" ");
    scope.set("closeData", scope.lookup("closeBtnData").call(scope.lookup(), scope.lookup("close")));
    idom$1.text(" ");
    if (scope.lookup("closeData")) {
      Temple__default.With(scope.lookup("closeData"), scope, function (scope) {
        idom$1.text(" ");
        idom$1.elementOpen("button", "5-0-0-1");
        decorators.render(scope, "class", function (scope) {
          return ["btn ", scope.lookup("className")].map(Temple__default.utils.toString).join("");
        });
        decorators.render(scope, "data-dismiss", "modal");
        decorators.render(scope, "absorb-attrs", function (scope) {
          return scope.lookup();
        });
        idom$1.text(" ");
        idom$1.autotext(function () {
          return scope.lookup("text");
        });
        idom$1.text(" ");
        idom$1.elementClose("button");
        idom$1.text(" ");
      });
    }
    idom$1.text(" ");
    scope.set("confirmData", scope.lookup("confirmBtnData").call(scope.lookup(), scope.lookup("confirm")));
    idom$1.text(" ");
    if (scope.lookup("confirmData")) {
      Temple__default.With(scope.lookup("confirmData"), scope, function (scope) {
        idom$1.text(" ");
        if (scope.lookup("form")) {
          idom$1.text(" ");
          idom$1.elementOpen("button", "9-0-0-1-0-1");
          decorators.render(scope, "type", "submit");
          decorators.render(scope, "class", function (scope) {
            return ["btn ", scope.lookup("className")].map(Temple__default.utils.toString).join("");
          });
          decorators.render(scope, "absorb-attrs", function (scope) {
            return scope.lookup();
          });
          idom$1.text(" ");
          idom$1.autotext(function () {
            return scope.lookup("text");
          });
          idom$1.text(" ");
          idom$1.elementClose("button");
          idom$1.text(" ");
        } else {
          idom$1.text(" ");
          idom$1.elementOpen("button", "9-0-0-1-1-1");
          decorators.render(scope, "class", function (scope) {
            return ["btn ", scope.lookup("className")].map(Temple__default.utils.toString).join("");
          });
          decorators.render(scope, "on-click", function (scope) {
            return ["confirm", scope.lookup("onconfirm")];
          });
          decorators.render(scope, "absorb-attrs", function (scope) {
            return scope.lookup();
          });
          idom$1.text(" ");
          idom$1.autotext(function () {
            return scope.lookup("text");
          });
          idom$1.text(" ");
          idom$1.elementClose("button");
          idom$1.text(" ");
        }
        idom$1.text(" ");
      });
    }
    idom$1.text(" ");
  });
  idom$1.text(" ");
});

Template["bs-modal-footer"].helpers({
  closeBtnData: function closeBtnData(value) {
    if (!value) return false;
    if (typeof value === "string") value = { text: value };
    return lodash.assign({ text: "Close", className: "btn-secondary" }, value);
  },
  confirmBtnData: function confirmBtnData(value) {
    if (!value) return false;
    if (typeof value === "string") value = { text: value };
    return lodash.assign({ text: "Confirm", className: "btn-success" }, value);
  }
});

function createContainer() {
	var data = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
	var id = data.id;
	var className = data.className;

	var cont = document.createElement("div");
	if (id) cont.id = id;
	cont.classList.add("modal", "fade");
	if (className) cont.classList.add(className);
	return cont;
}

function create(node) {
	var data = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

	if (node && !node.nodeType) {
		;

		var _ref = [node, null];
		data = _ref[0];
		node = _ref[1];
	}function hide() {
		$el.modal("hide");
	}

	var cont = createContainer(data);
	data = lodash.merge({
		form: false,
		header: true,
		footer: true,
		close: true,
		confirm: false,
		destroyOnHide: true,
		hideOnConfirm: true,
		invokeHide: hide
	}, data);

	var comp = Temple__default.paint("bs-modal-content", cont, data);

	var $el = comp.$el = jQuery(cont);
	comp.container = cont;

	comp.appendTo = function (node) {
		if (typeof node === "string") node = document.querySelector(node);
		node.appendChild(cont);
		return comp;
	};

	comp.show = function (node) {
		if (node) comp.appendTo(node);else if (!comp.container.parentNode) comp.appendTo("body");
		$el.modal("show");
		return comp;
	};

	comp.hide = function () {
		hide();
		return comp;
	};

	comp.destroy = function () {
		comp.stop();
		if (cont.parentNode) {
			cont.parentNode.removeChild(cont);
		}
	};

	$el.on("hidden.bs.modal", function () {
		if (data.destroyOnHide) comp.destroy();
	});

	if (node) comp.appendTo(node);

	return comp;
}

function open(node, data) {
	if (node && !node.nodeType) {
		;
		var _ref2 = [node, null];
		data = _ref2[0];
		node = _ref2[1];
	}var modal = create(node, data);
	modal.show();
	return modal;
}

function confirm(msg, data, fn) {
	if (typeof data === "function") {
		;

		var _ref3 = [data, {}];
		fn = _ref3[0];
		data = _ref3[1];
	}return open(document.body, lodash.merge({
		content: msg,
		onconfirm: fn,
		header: false,
		footer: {
			close: "Cancel",
			confirm: { className: "btn-primary", text: "Okay" }
		},
		className: "modal-confirm"
	}, data));
}

exports.createContainer = createContainer;
exports.create = create;
exports.open = open;
exports.confirm = confirm;
